# TODO:
# - any valid CMAKE_BUILD_TYPE causes overriding of our optflags
#   (and default non-verbose makefiles are hiding it!)
# - rpmldflags/rpmcppflags are not passed through %%cmake macro at all
#   (is there any standard way???)
#
# Conditional build:
%bcond_with	bootstrap	# use internal versions of some libraries
%bcond_without	gui		# don't build gui package
%bcond_without	tests		# do not perform "make test"

Summary:	Cross-platform, open-source make system
Summary(pl.UTF-8):	Wieloplatformowy system make o otwartych źródłach
Name:		cmake
Version:	2.8.12.2
Release:	2
License:	BSD
Group:		Development/Building
Source0:	http://www.cmake.org/files/v2.8/%{name}-%{version}.tar.gz
# Source0-md5:	17c6513483d23590cbce6957ec6d1e66
Patch0:		%{name}-lib64.patch
Patch1:		%{name}-helpers.patch
Patch2:		%{name}-findruby.patch
Patch3:		%{name}-tests.patch
Patch4:		%{name}-freetype2.patch
Patch5:		%{name}-findruby2.patch
URL:		http://www.cmake.org/
%{?with_gui:BuildRequires:	QtGui-devel}
BuildRequires:	libarchive-devel
BuildRequires:	libstdc++-devel
BuildRequires:	ncurses-devel > 5.9-3
%{?with_gui:BuildRequires:	qt4-build}
%{?with_gui:BuildRequires:	qt4-qmake}
BuildRequires:	rpmbuild(macros) >= 1.167
%{!?with_bootstrap:BuildRequires:	xmlrpc-c-devel >= 1.4.12-2}
Requires:	filesystem >= 3.0-52
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
CMake is used to control the software compilation process using simple
platform and compiler independent configuration files. CMake generates
native makefiles and workspaces that can be used in the compiler
environment of your choice. CMake is quite sophisticated: it is
possible to support complex environments requiring system
configuration, pre-processor generation, code generation, and template
instantiation.

%description -l pl.UTF-8
CMake służy do sterowania procesem kompilacji oprogramowania przy
użyciu prostych plików konfiguracyjnych niezależnych od platformy i
kompilatora. CMake generuje natywne pliki makefile i workspace,
których można używać w wybranym środowisku kompilatora. CMake jest
dość wyrafinowany: może obsłużyć złożone środowiska wymagające
konfiguracji systemu, generowanie preprocesora, generowanie kodu i
dziedziczenie szablonów.

%package gui
Summary:	Qt GUI for CMake
Summary(pl.UTF-8):	Graficzny interfejs użytkownika Qt dla CMake
Group:		Development/Tools
Requires:	%{name} = %{version}-%{release}

%description gui
This package contains the Qt based GUI for CMake.

%description gui -l pl.UTF-8
Ten pakiet zawiera oparty na Qt graficzny interfejs użytkownika dla
CMake.

%package emacs
Summary:	Emacs mode for cmake files
Summary(pl.UTF-8):	Tryb Emacsa dla plików cmake'a
Group:		Development/Tools

%description emacs
Emacs mode for cmake files.

%description emacs -l pl.UTF-8
Tryb Emacsa dla plików cmake'a.

%package -n bash-completion-%{name}
Summary:	bash-completion for cmake
Summary(pl.UTF-8):	Bashowe dopełnianie parametrów dla cmake'a
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	bash-completion >= 2.0
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description -n bash-completion-%{name}
bash-completion for cmake.

%description -n bash-completion-%{name} -l pl.UTF-8
Bashowe dopełnianie parametrów dla cmake'a.

%prep
%setup -q
%if "%{_lib}" == "lib64"
%patch0 -p1
%endif
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

cat > "init.cmake" <<EOF
SET (CURSES_INCLUDE_PATH "/usr/include/ncurses" CACHE PATH " " FORCE)
SET (CMAKE_INSTALL_SYSCONFDIR "%{_sysconfdir}" CACHE PATH " " FORCE)
SET (CMAKE_INSTALL_DATADIR "%{_datadir}" CACHE PATH " " FORCE)
EOF

# cleanup backups after patching, modules are copied as-is
find '(' -name '*~' -o -name '*.orig' ')' -print0 | xargs -0 -r -l512 rm -f

%build
export CC="%{__cc}"
export CXX="%{__cxx}"
export CFLAGS="%{rpmcflags}"
export CXXFLAGS="%{rpmcxxflags}"
export LDFLAGS="%{rpmldflags}"
./bootstrap \
	--prefix=%{_prefix} \
	--mandir=/share/man \
	--datadir=/share/cmake \
	--init=init.cmake \
	%{!?with_bootstrap:--system-libs} \
	%{?with_gui:--qt-gui} \
	--qt-qmake=/usr/bin/qmake-qt4 \
	--verbose

%{__make} VERBOSE=1

%{?with_tests:%{__make} test}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} -r $RPM_BUILD_ROOT%{_prefix}/doc

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc ChangeLog.* Copyright.txt *.gif Docs/{cmake,ctest}.{txt,html}
%attr(755,root,root) %{_bindir}/ccmake
%attr(755,root,root) %{_bindir}/cmake
%attr(755,root,root) %{_bindir}/cpack
%attr(755,root,root) %{_bindir}/ctest
%{_mandir}/man1/ccmake.1*
%{_mandir}/man1/cmake.1*
%{_mandir}/man1/cmakecommands.1*
%{_mandir}/man1/cmakecompat.1*
%{_mandir}/man1/cmakemodules.1*
%{_mandir}/man1/cmakepolicies.1*
%{_mandir}/man1/cmakeprops.1*
%{_mandir}/man1/cmakevars.1*
%{_mandir}/man1/cpack.1*
%{_mandir}/man1/ctest.1*
# top cmake/Modules dirs belong to filesystem
%{_datadir}/cmake/Modules/.NoDartCoverage
%{_datadir}/cmake/Modules/*
%{_datadir}/cmake/Templates
%{_datadir}/cmake/editors
%{_datadir}/cmake/include
%{_aclocaldir}/cmake.m4

%if %{with gui}
%files gui
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/cmake-gui
%{_datadir}/mime/packages/cmakecache.xml
%{_desktopdir}/CMake.desktop
%{_pixmapsdir}/CMakeSetup32.png
%{_mandir}/man1/cmake-gui.1*
%endif

%files emacs
%defattr(644,root,root,755)
%{_datadir}/emacs/site-lisp/cmake-mode.el

%files -n bash-completion-%{name}
%defattr(644,root,root,755)
%{_datadir}/bash-completion/completions/cmake
%{_datadir}/bash-completion/completions/cpack
%{_datadir}/bash-completion/completions/ctest
%changelog
* Tue Sep 16 2014 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/cmake.git;a=log;h=master

* Tue Aug 26 2014 Jan Rękorajski <baggins@pld-linux.org> 6f0c4bc
- rel 2

* Tue Aug 26 2014 Jan Rękorajski <baggins@pld-linux.org> b343cdb
- cleanup patching artifacts

* Tue Aug 26 2014 Jan Rękorajski <baggins@pld-linux.org> a048aac
- added fix for ruby 2.x b/c of moved RUBY_CONFIG_INCLUDE_DIR

* Sat Mar 15 2014 Elan Ruusamäe <glen@delfi.ee> 6465d90
- noarch bash completions

* Sun Jan 19 2014 Jakub Bogusz <qboosh@pld-linux.org> aae1b47
- updated to 2.8.12.2; ExternalProject tests still fail

* Fri Dec 06 2013 Jakub Bogusz <qboosh@pld-linux.org> 0ea0e36
- added freetype2 patch (fixes freetype 2.5.1 detection)
- release 2

* Fri Nov 08 2013 Jakub Bogusz <qboosh@pld-linux.org> de784c5
- added tests patch (fixes some curl-related failures; a few still exist, probably git related, but reason unknown - lacking logs)

* Thu Nov 07 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> e3d2f45
- up to 2.8.12.1

* Sun Oct 20 2013 Jakub Bogusz <qboosh@pld-linux.org> a9b1845
- updated to 2.8.12
- updated helpers patch; adjusted bash-completions for b-c 2
- removed obsolete cmake-git patch

* Thu Jul 11 2013 Jakub Bogusz <qboosh@pld-linux.org> da5de91
- updated to 2.8.11.2

* Sun Jul 07 2013 Jan Rękorajski <baggins@pld-linux.org> afb70bd
- release 3 (by relup.sh)

* Fri Jun 14 2013 Jakub Bogusz <qboosh@pld-linux.org> eead9c1
- tests bcond desc

* Tue Jun 11 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 53357b6
- rel 2; fix imagemagick detection from upstream

* Sun Jun 09 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 1fbe3ed
- up to 2.8.11.1

* Sat Jun 08 2013 Elan Ruusamäe <glen@delfi.ee> fe667d6
- add FindRuby patch from fedora

* Sun May 19 2013 Jakub Bogusz <qboosh@pld-linux.org> 552867d
- updated to 2.8.11

* Thu Nov 29 2012 Jakub Bogusz <qboosh@pld-linux.org> 2736b14
- updated to 2.8.10.2

* Sun Nov 11 2012 Jan Rękorajski <baggins@pld-linux.org> b739aa1
- rebuild with expat 2.1.0
- release 2 (by relup.sh)

* Sun Nov 11 2012 Jakub Bogusz <qboosh@pld-linux.org> c3e2cca
- updated to 2.8.10.1

* Sat Nov 03 2012 Paweł Sikora <pawel.sikora@agmk.net> f13d1e4
- updated to 2.8.10.

